#!/usr/bin/env node

// Connect to local database
//   DRIVER=IBM i Access ODBC Driver -- which odbc driver to use
//   SYSTEM=localhost -- ip address or host to connect to
//   NAM=1 -- naming=*sys
//   CMT=0 -- commit=*none
//   UNICODESQL=1 -- use unicode statements (vs EBCDIC)
//   DBQ=,SKLEMENT -- DBQ sets library list. Begin with comma to add to end. 
//       This example adds library SKLEMENT to end of library list

const odbc = require("odbc");
odbc.connect(`DSN=*LOCAL;NAM=1;CMT=0;DBQ=,*USRLIBL,SKLEMENT`, (error, conn) => {

  // Create an Excel workbook with one worksheet named "Orders".

  const Excel = require("exceljs");
  const workbook = new Excel.Workbook();
  let worksheet = workbook.addWorksheet("Orders");


  // Add column definitions to the worksheet.
  // The column keys are named after the DB2 column names.
  worksheet.columns = [
      { header: "Order #", key: "ORDERREF", width: 9 },
      { header: "Line #", key: "ORDERLINE", width: 7, style: { numFmt: "0" } },
      { header: "Product #", key: "PRODREF", width: 15 },
      { header: "Ordered Qty", key: "ORDERQTY", width: 12, style: { numFmt: "0" }  },
      { header: "Extended Amount", key: "SALETOTAL", width: 17, style: { numFmt: "$#,##0.00_);[Red]($#,##0.00)" } }
  ];
  worksheet.getRow(1).font = { name: "Calibri", size: 11, bold: true };


  // Statement will read from "sales order detail" table.

  conn.query("select ORDERREF, ORDERLINE, PRODREF, ORDERQTY, SALETOTAL" +
             "  from SALESDTL", (error, result) => {
  
    // Loop through the rows returned in the result set
  
    result.forEach((row) => {
      worksheet.addRow(row); 
    });
      
    // Write the worksheet to the file system, in the current working directory.
    workbook.xlsx.writeFile("orders.xlsx");
  
  });
  
});

